@@ -2,8 +2,8 @@
                           version.h  -  description
                              -------------------
     begin                : Mon March 3 2003
-    copyright            : (C) 2003-2015 by Andre Simon
-    email                : andre.simon1@gmx.de
+    copyright            : (C) 2003-2019 by Andre Simon
+    email                : a.simon@mailbox.org
  ***************************************************************************/
 
 
@@ -28,9 +28,9 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef VERSION_H
 #define VERSION_H
 
-#define HIGHLIGHT_VERSION "3.23"
+#define HIGHLIGHT_VERSION "3.50"
 
 #define HIGHLIGHT_URL "http://www.andre-simon.de/"
-#define HIGHLIGHT_EMAIL "andre.simon1@gmx.de"
+#define HIGHLIGHT_EMAIL "a.simon@mailbox.org"
 
 #endif
